@@ -11,7 +11,7 @@
  * C identifiers up into keywords and SWIG directives.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_cscanner_c[] = "$Id: cscanner.c 9837 2007-05-26 00:06:45Z wsfulton $";
+char cvsroot_cscanner_c[] = "$Id: cscanner.c 10511 2008-05-30 16:11:27Z olly $";
 
 #include "cparse.h"
 #include "parser.h"
@@ -423,13 +423,15 @@ int yylook(void) {
       {
 	String *cmt = Scanner_text(scan);
 	char *loc = Char(cmt);
-	if ((strncmp(loc,"/*@SWIG@",6) == 0) && (loc[Len(cmt)-3] == '@')) {
+	if ((strncmp(loc,"/*@SWIG",7) == 0) && (loc[Len(cmt)-3] == '@')) {
 	  scanner_locator(cmt);
 	}
       }
       break;
     case SWIG_TOKEN_ENDLINE:
       break;
+    case SWIG_TOKEN_BACKSLASH:
+      break;
     default:
       Swig_error(cparse_file, cparse_line, "Illegal token '%s'.\n", Scanner_text(scan));
       return (ILLEGAL);
