@@ -16,7 +16,7 @@
  * numbers in this file.
  * ----------------------------------------------------------------------------- */
 
-/* $Header: /cvsroot/swig/SWIG/Source/Include/swigwarn.h,v 1.42 2006/11/01 23:54:50 wsfulton Exp $ */
+/* $Id: swigwarn.h 10450 2008-05-14 22:12:31Z wsfulton $ */
 
 #ifndef SWIGWARN_H_
 #define SWIGWARN_H_
@@ -161,6 +161,8 @@
 #define WARN_TYPEMAP_DIRECTOROUT_UNDEF 471
 #define WARN_TYPEMAP_TYPECHECK_UNDEF   472
 #define WARN_TYPEMAP_DIRECTOROUT_PTR   473
+#define WARN_TYPEMAP_OUT_OPTIMAL_IGNORED  474
+#define WARN_TYPEMAP_OUT_OPTIMAL_MULTIPLE 475
 
 /* -- Fragments -- */
 #define WARN_FRAGMENT_NOT_FOUND       490
@@ -185,6 +187,7 @@
 #define WARN_LANG_OVERLOAD_IGNORED    516
 #define WARN_LANG_DIRECTOR_ABSTRACT   517
 #define WARN_LANG_PORTABILITY_FILENAME 518
+#define WARN_LANG_TEMPLATE_METHOD_IGNORE 519
 
 /* -- Reserved (600-799) -- */
 
