@@ -1,3 +1,7 @@
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=8:smarttab:
+ */
+
 /* ----------------------------------------------------------------------------
  * See the LICENSE file for information on copyright, usage and redistribution
  * of SWIG, and the README file for authors - http://www.swig.org/release.html.
@@ -7,7 +11,7 @@
  * Perl5 language module for SWIG.
  * ------------------------------------------------------------------------- */
 
-char cvsroot_perl5_cxx[] = "$Id: perl5.cxx 10336 2008-04-03 11:31:41Z jason_e_stewart $";
+char cvsroot_perl5_cxx[] = "$Id: perl5.cxx 10453 2008-05-15 21:18:44Z wsfulton $";
 
 #include "swigmod.h"
 #include "cparse.h"
@@ -41,17 +45,21 @@ static String *pmfile = 0;
 /*
  * module
  *   set by the %module directive, e.g. "Xerces". It will determine
- *   the name of the .pm file, and the dynamic library.
+ *   the name of the .pm file, and the dynamic library, and the name
+ *   used by any module wanting to %import the module.
  */
 static String *module = 0;
 
 /*
- * fullmodule
- *   the fully namespace qualified name of the module, e.g. "XML::Xerces"
- *   it will be used to set the package namespace in the .pm file, as
- *   well as the name of the initialization methods in the glue library
+ * namespace_module
+ *   the fully namespace qualified name of the module. It will be used
+ *   to set the package namespace in the .pm file, as well as the name
+ *   of the initialization methods in the glue library. This will be
+ *   the same as module, above, unless the %module directive is given
+ *   the 'package' option, e.g. %module(package="Foo::Bar") "baz"
  */
-static String *fullmodule = 0;
+static String       *namespace_module = 0;
+
 /*
  * cmodule
  *   the namespace of the internal glue code, set to the value of
@@ -59,6 +67,13 @@ static String *fullmodule = 0;
  */
 static String *cmodule = 0;
 
+/*
+ * dest_package
+ *   an optional namespace to put all classes into. Specified by using
+ *   the %module(package="Foo::Bar") "baz" syntax
+ */
+static String       *dest_package = 0;
+
 static String *command_tab = 0;
 static String *constant_tab = 0;
 static String *variable_tab = 0;
@@ -71,7 +86,10 @@ static File *f_pm = 0;
 static String *pm;		/* Package initialization code */
 static String *magic;		/* Magic variable wrappers     */
 
-static int is_static = 0;
+static int staticoption = 0;
+
+// controlling verbose output
+static int          verbose = 0;
 
 /* The following variables are used to manage Perl5 classes */
 
@@ -146,7 +164,7 @@ public:
 	  export_all = 1;
 	  Swig_mark_arg(i);
 	} else if (strcmp(argv[i], "-static") == 0) {
-	  is_static = 1;
+	  staticoption = 1;
 	  Swig_mark_arg(i);
 	} else if ((strcmp(argv[i], "-shadow") == 0) || ((strcmp(argv[i], "-proxy") == 0))) {
 	  blessed = 1;
@@ -166,6 +184,9 @@ public:
 	  i++;
 	  pmfile = NewString(argv[i]);
 	  Swig_mark_arg(i);
+	} else if (strcmp(argv[i],"-v") == 0) {
+	    Swig_mark_arg(i);
+	    verbose++;
 	} else if (strcmp(argv[i], "-cppcast") == 0) {
 	  cppcast = 1;
 	  Swig_mark_arg(i);
@@ -237,16 +258,43 @@ public:
     Printf(f_runtime, "#define SWIG_CASTRANK_MODE\n");
 
 
-    module = Copy(Getattr(n, "name"));
+    // Is the imported module in another package?  (IOW, does it use the
+    // %module(package="name") option and it's different than the package
+    // of this module.)
+    Node *mod = Getattr(n, "module");
+    Node *options = Getattr(mod, "options");
+    module = Copy(Getattr(n,"name"));
+
+    if (verbose > 0) {
+      fprintf(stdout, "top: using module: %s\n", Char(module));
+    }
+
+    dest_package = options ? Getattr(options, "package") : 0;
+    if (dest_package) {
+      namespace_module = Copy(dest_package);
+      if (verbose > 0) {
+	fprintf(stdout, "top: Found package: %s\n",Char(dest_package));
+      }
+    } else {
+      namespace_module = Copy(module);
+      if (verbose > 0) {
+	fprintf(stdout, "top: No package found\n");
+      }
+    }
+    String *underscore_module = Copy(module);
+    Replaceall(underscore_module,":","_");
+
+    if (verbose > 0) {
+      fprintf(stdout, "top: using namespace_module: %s\n", Char(namespace_module));
+    }
 
     /* If we're in blessed mode, change the package name to "packagec" */
 
     if (blessed) {
-      cmodule = NewStringf("%sc", module);
+      cmodule = NewStringf("%sc",namespace_module);
     } else {
-      cmodule = NewString(module);
+      cmodule = NewString(namespace_module);
     }
-    fullmodule = NewString(module);
 
     /* Create a .pm file
      * Need to strip off any prefixes that might be found in
@@ -277,12 +325,11 @@ public:
       Swig_register_filebyname("perl", f_pm);
     }
     {
-      String *tmp = NewString(fullmodule);
-      Replaceall(tmp, ":", "_");
-      Printf(f_header, "#define SWIG_init    boot_%s\n\n", tmp);
-      Printf(f_header, "#define SWIG_name   \"%s::boot_%s\"\n", cmodule, tmp);
-      Printf(f_header, "#define SWIG_prefix \"%s::\"\n", cmodule);
-      Delete(tmp);
+      String *boot_name = NewStringf("boot_%s", underscore_module);
+      Printf(f_header,"#define SWIG_init    %s\n\n", boot_name);
+      Printf(f_header,"#define SWIG_name   \"%s::%s\"\n", cmodule, boot_name);
+      Printf(f_header,"#define SWIG_prefix \"%s::\"\n", cmodule);
+      Delete(boot_name);
     }
 
     Printf(f_pm, "# This file was automatically generated by SWIG (http://www.swig.org).\n");
@@ -291,14 +338,20 @@ public:
     Printf(f_pm, "# Don't modify this file, modify the SWIG interface instead.\n");
     Printf(f_pm, "\n");
 
-    Printf(f_pm, "package %s;\n", fullmodule);
+    Printf(f_pm, "package %s;\n", module);
 
-    Printf(f_pm, "require Exporter;\n");
-    if (!is_static) {
-      Printf(f_pm, "require DynaLoader;\n");
-      Printf(f_pm, "@ISA = qw(Exporter DynaLoader);\n");
+    /* 
+     * If the package option has been given we are placing our
+     *   symbols into some other packages namespace, so we do not
+     *   mess with @ISA or require for that package
+     */
+    if (dest_package) {
+      Printf(f_pm,"use base qw(DynaLoader);\n");
     } else {
-      Printf(f_pm, "@ISA = qw(Exporter);\n");
+      Printf(f_pm,"use base qw(Exporter);\n");
+      if (!staticoption) {
+	Printf(f_pm,"use base qw(DynaLoader);\n");
+      }
     }
 
     /* Start creating magic code */
@@ -306,8 +359,8 @@ public:
     Printv(magic,
            "#ifdef __cplusplus\nextern \"C\" {\n#endif\n\n",
 	   "#ifdef PERL_OBJECT\n",
-	   "#define MAGIC_CLASS _wrap_", module, "_var::\n",
-	   "class _wrap_", module, "_var : public CPerlObj {\n",
+	   "#define MAGIC_CLASS _wrap_", underscore_module, "_var::\n",
+	   "class _wrap_", underscore_module, "_var : public CPerlObj {\n",
 	   "public:\n",
 	   "#else\n",
 	   "#define MAGIC_CLASS\n",
@@ -374,61 +427,73 @@ public:
 
     Printf(f_pm, "package %s;\n", cmodule);
 
-    if (!is_static) {
-      Printf(f_pm, "bootstrap %s;\n", fullmodule);
+    if (!staticoption) {
+      Printf(f_pm,"bootstrap %s;\n", module);
     } else {
-      String *tmp = NewString(fullmodule);
-      Replaceall(tmp, ":", "_");
-      Printf(f_pm, "boot_%s();\n", tmp);
-      Delete(tmp);
+      Printf(f_pm,"package %s;\n", cmodule);
+      Printf(f_pm,"boot_%s();\n", underscore_module);
     }
-    Printf(f_pm, "package %s;\n", fullmodule);
-    Printf(f_pm, "@EXPORT = qw( %s);\n", exported);
+
+    Printf(f_pm, "package %s;\n", module);
+    /* 
+     * If the package option has been given we are placing our
+     *   symbols into some other packages namespace, so we do not
+     *   mess with @EXPORT
+     */
+    if (!dest_package) {
+      Printf(f_pm,"@EXPORT = qw(%s);\n", exported);
+    }
+
     Printf(f_pm, "%s", pragma_include);
 
     if (blessed) {
 
-      Printv(base, "\n# ---------- BASE METHODS -------------\n\n", "package ", fullmodule, ";\n\n", NIL);
+      /*
+       * These methods will be duplicated if package 
+       *   has been specified, so we do not output them
+       */
+      if (!dest_package) {
+	Printv(base, "\n# ---------- BASE METHODS -------------\n\n", "package ", namespace_module, ";\n\n", NIL);
 
-      /* Write out the TIE method */
+	/* Write out the TIE method */
 
-      Printv(base, "sub TIEHASH {\n", tab4, "my ($classname,$obj) = @_;\n", tab4, "return bless $obj, $classname;\n", "}\n\n", NIL);
+	Printv(base, "sub TIEHASH {\n", tab4, "my ($classname,$obj) = @_;\n", tab4, "return bless $obj, $classname;\n", "}\n\n", NIL);
 
-      /* Output a CLEAR method.   This is just a place-holder, but by providing it we
-       * can make declarations such as
-       *     %$u = ( x => 2, y=>3, z =>4 );
-       *
-       * Where x,y,z are the members of some C/C++ object. */
+	/* Output a CLEAR method.   This is just a place-holder, but by providing it we
+	 * can make declarations such as
+	 *     %$u = ( x => 2, y=>3, z =>4 );
+	 *
+	 * Where x,y,z are the members of some C/C++ object. */
 
-      Printf(base, "sub CLEAR { }\n\n");
+	Printf(base, "sub CLEAR { }\n\n");
 
-      /* Output default firstkey/nextkey methods */
+	/* Output default firstkey/nextkey methods */
 
-      Printf(base, "sub FIRSTKEY { }\n\n");
-      Printf(base, "sub NEXTKEY { }\n\n");
+	Printf(base, "sub FIRSTKEY { }\n\n");
+	Printf(base, "sub NEXTKEY { }\n\n");
 
-      /* Output a FETCH method.  This is actually common to all classes */
-      Printv(base,
-	     "sub FETCH {\n",
-	     tab4, "my ($self,$field) = @_;\n", tab4, "my $member_func = \"swig_${field}_get\";\n", tab4, "$self->$member_func();\n", "}\n\n", NIL);
+	/* Output a FETCH method.  This is actually common to all classes */
+	Printv(base,
+	       "sub FETCH {\n",
+	       tab4, "my ($self,$field) = @_;\n", tab4, "my $member_func = \"swig_${field}_get\";\n", tab4, "$self->$member_func();\n", "}\n\n", NIL);
 
-      /* Output a STORE method.   This is also common to all classes (might move to base class) */
+	/* Output a STORE method.   This is also common to all classes (might move to base class) */
 
-      Printv(base,
-	     "sub STORE {\n",
-	     tab4, "my ($self,$field,$newval) = @_;\n",
-	     tab4, "my $member_func = \"swig_${field}_set\";\n", tab4, "$self->$member_func($newval);\n", "}\n\n", NIL);
+	Printv(base,
+	       "sub STORE {\n",
+	       tab4, "my ($self,$field,$newval) = @_;\n",
+	       tab4, "my $member_func = \"swig_${field}_set\";\n", tab4, "$self->$member_func($newval);\n", "}\n\n", NIL);
 
-      /* Output a 'this' method */
+	/* Output a 'this' method */
 
-      Printv(base, "sub this {\n", tab4, "my $ptr = shift;\n", tab4, "return tied(%$ptr);\n", "}\n\n", NIL);
+	Printv(base, "sub this {\n", tab4, "my $ptr = shift;\n", tab4, "return tied(%$ptr);\n", "}\n\n", NIL);
 
-      Printf(f_pm, "%s", base);
+	Printf(f_pm, "%s", base);
+      }
 
       /* Emit function stubs for stand-alone functions */
-
       Printf(f_pm, "\n# ------- FUNCTION WRAPPERS --------\n\n");
-      Printf(f_pm, "package %s;\n\n", fullmodule);
+      Printf(f_pm, "package %s;\n\n", namespace_module);
       Printf(f_pm, "%s", func_stubs);
 
       /* Emit package code for different classes */
@@ -437,14 +502,14 @@ public:
       if (num_consts > 0) {
 	/* Emit constant stubs */
 	Printf(f_pm, "\n# ------- CONSTANT STUBS -------\n\n");
-	Printf(f_pm, "package %s;\n\n", fullmodule);
+	Printf(f_pm, "package %s;\n\n", namespace_module);
 	Printf(f_pm, "%s", const_stubs);
       }
 
       /* Emit variable stubs */
 
       Printf(f_pm, "\n# ------- VARIABLE STUBS --------\n\n");
-      Printf(f_pm, "package %s;\n\n", fullmodule);
+      Printf(f_pm, "package %s;\n\n", namespace_module);
       Printf(f_pm, "%s", var_stubs);
     }
 
@@ -455,6 +520,8 @@ public:
     Close(f_pm);
     Delete(f_pm);
     Delete(base);
+    Delete(dest_package);
+    Delete(underscore_module);
 
     /* Close all of the files */
     Dump(f_header, f_runtime);
@@ -522,7 +589,7 @@ public:
     Printv(f->def, "XS(", wname, ") {\n", "{\n",	/* scope to destroy C++ objects before croaking */
 	   NIL);
 
-    emit_args(d, l, f);
+    emit_parameter_variables(l, f);
     emit_attach_parmmaps(l, f);
     Setattr(n, "wrap:parms", l);
 
@@ -655,9 +722,10 @@ public:
 
     /* Now write code to make the function call */
 
-    emit_action(n, f);
+    Swig_director_emit_dynamic_cast(n, f);
+    String *actioncode = emit_action(n);
 
-    if ((tm = Swig_typemap_lookup_new("out", n, "result", 0))) {
+    if ((tm = Swig_typemap_lookup_out("out", n, "result", f, actioncode))) {
       SwigType *t = Getattr(n, "type");
       Replaceall(tm, "$source", "result");
       Replaceall(tm, "$target", "ST(argvi)");
@@ -676,6 +744,7 @@ public:
     } else {
       Swig_warning(WARN_TYPEMAP_OUT_UNDEF, input_file, line_number, "Unable to use return type %s in function %s.\n", SwigType_str(d, 0), name);
     }
+    emit_return_variable(n, d, f);
 
     /* If there were any output args, take care of them. */
 
@@ -686,13 +755,13 @@ public:
     Printv(f->code, cleanup, NIL);
 
     if (GetFlag(n, "feature:new")) {
-      if ((tm = Swig_typemap_lookup_new("newfree", n, "result", 0))) {
+      if ((tm = Swig_typemap_lookup("newfree", n, "result", 0))) {
 	Replaceall(tm, "$source", "result");
 	Printf(f->code, "%s\n", tm);
       }
     }
 
-    if ((tm = Swig_typemap_lookup_new("ret", n, "result", 0))) {
+    if ((tm = Swig_typemap_lookup("ret", n, "result", 0))) {
       Replaceall(tm, "$source", "result");
       Printf(f->code, "%s\n", tm);
     }
@@ -787,13 +856,13 @@ public:
       Printv(setf->code, tab4, "MAGIC_PPERL\n", NIL);
 
       /* Check for a few typemaps */
-      tm = Swig_typemap_lookup_new("varin", n, name, 0);
+      tm = Swig_typemap_lookup("varin", n, name, 0);
       if (tm) {
 	Replaceall(tm, "$source", "sv");
 	Replaceall(tm, "$target", name);
 	Replaceall(tm, "$input", "sv");
 	/* Printf(setf->code,"%s\n", tm); */
-	emit_action_code(n, setf, tm);
+	emit_action_code(n, setf->code, tm);
       } else {
 	Swig_warning(WARN_TYPEMAP_VARIN_UNDEF, input_file, line_number, "Unable to set variable of type %s.\n", SwigType_str(t, 0));
 	return SWIG_NOWRAP;
@@ -810,7 +879,7 @@ public:
     Printf(getf->def, "SWIGCLASS_STATIC int %s(pTHX_ SV *sv, MAGIC *SWIGUNUSEDPARM(mg)) {\n", get_name);
     Printv(getf->code, tab4, "MAGIC_PPERL\n", NIL);
 
-    if ((tm = Swig_typemap_lookup_new("varout", n, name, 0))) {
+    if ((tm = Swig_typemap_lookup("varout", n, name, 0))) {
       Replaceall(tm, "$target", "sv");
       Replaceall(tm, "$result", "sv");
       Replaceall(tm, "$source", name);
@@ -820,7 +889,7 @@ public:
 	Replaceall(tm, "$shadow", "0");
       }
       /* Printf(getf->code,"%s\n", tm); */
-      addfail = emit_action_code(n, getf, tm);
+      addfail = emit_action_code(n, getf->code, tm);
     } else {
       Swig_warning(WARN_TYPEMAP_VAROUT_UNDEF, input_file, line_number, "Unable to read variable of type %s\n", SwigType_str(t, 0));
       DelWrapper(setf);
@@ -913,7 +982,7 @@ public:
       value = Char(wname);
     }
 
-    if ((tm = Swig_typemap_lookup_new("consttab", n, name, 0))) {
+    if ((tm = Swig_typemap_lookup("consttab", n, name, 0))) {
       Replaceall(tm, "$source", value);
       Replaceall(tm, "$target", name);
       Replaceall(tm, "$value", value);
@@ -923,7 +992,7 @@ public:
 	Replaceall(tm, "$shadow", "0");
       }
       Printf(constant_tab, "%s,\n", tm);
-    } else if ((tm = Swig_typemap_lookup_new("constcode", n, name, 0))) {
+    } else if ((tm = Swig_typemap_lookup("constcode", n, name, 0))) {
       Replaceall(tm, "$source", value);
       Replaceall(tm, "$target", name);
       Replaceall(tm, "$value", value);
@@ -1071,11 +1140,28 @@ public:
     }
 
     /* Do some work on the class name */
-    actualpackage = Getattr(clsmodule, "name");
-    if ((!compat) && (!Strchr(symname, ':'))) {
-      fullname = NewStringf("%s::%s", actualpackage, symname);
+    if (verbose > 0) {
+      fprintf(stdout, "setclassname: Found sym:name: %s\n", Char(symname));
+      fprintf(stdout, "setclassname: Found module: %s\n", Char(clsmodule));
+      fprintf(stdout, "setclassname: No package found\n");
+    }
+
+    if (dest_package) {
+      fullname = NewStringf("%s::%s", namespace_module, symname);
     } else {
-      fullname = NewString(symname);
+      actualpackage = Getattr(clsmodule,"name");
+
+      if (verbose > 0) {
+	fprintf(stdout, "setclassname: Found actualpackage: %s\n", Char(actualpackage));
+      }
+      if ((!compat) && (!Strchr(symname,':'))) {
+	fullname = NewStringf("%s::%s",actualpackage,symname);
+      } else {
+	fullname = NewString(symname);
+      }
+    }
+    if (verbose > 0) {
+      fprintf(stdout, "setclassname: setting proxy: %s\n", Char(fullname));
     }
     Setattr(n, "perl5:proxy", fullname);
   }
@@ -1115,7 +1201,7 @@ public:
 
       /* Use the fully qualified name of the Perl class */
       if (!compat) {
-	fullclassname = NewStringf("%s::%s", fullmodule, class_name);
+	fullclassname = NewStringf("%s::%s", namespace_module, class_name);
       } else {
 	fullclassname = NewString(class_name);
       }
@@ -1200,6 +1286,8 @@ public:
 	    fprintf(stderr,"Unknown operator: %s\n", name);
 	  }
 	}
+	Printv(pm, tab4,
+               "\"=\" => sub { my $class = ref($_[0]); $class->new($_[0]) },\n", NIL);
 	Printv(pm, tab4, "\"fallback\" => 1;\n", NIL);
       }
       // make use strict happy
@@ -1226,8 +1314,8 @@ public:
       }
 
       /* Module comes last */
-      if (!compat || Cmp(fullmodule, fullclassname)) {
-	Printv(pm, " ", fullmodule, NIL);
+      if (!compat || Cmp(namespace_module, fullclassname)) {
+	Printv(pm, " ", namespace_module, NIL);
       }
 
       Printf(pm, " );\n");
