@@ -7,7 +7,7 @@
  * Main header file for SWIG modules.
  * ----------------------------------------------------------------------------- */
 
-/* $Id: swigmod.h 10301 2008-03-09 20:21:14Z xavier98 $ */
+/* $Id: swigmod.h 10450 2008-05-14 22:12:31Z wsfulton $ */
 
 #ifndef SWIG_SWIGMOD_H_
 #define SWIG_SWIGMOD_H_
@@ -232,6 +232,9 @@ public:
   /* Allow director protected members related code generation */
   void allow_dirprot(int val = 1);
 
+  /* Allow all protected members code generation (for directors) */
+  void allow_allprotected(int val = 0);
+
   /* Returns the dirprot mode */
   int dirprot_mode() const;
 
@@ -307,7 +310,8 @@ private:
 };
 
 int SWIG_main(int, char **, Language *);
-void emit_args(SwigType *, ParmList *, Wrapper *f);
+void emit_parameter_variables(ParmList *l, Wrapper *f);
+void emit_return_variable(Node *n, SwigType *rt, Wrapper *f);
 void SWIG_exit(int);		/* use EXIT_{SUCCESS,FAILURE} */
 void SWIG_config_file(const String_or_char *);
 const String *SWIG_output_directory();
@@ -319,8 +323,8 @@ int emit_num_required(ParmList *);
 int emit_isvarargs(ParmList *);
 void emit_attach_parmmaps(ParmList *, Wrapper *f);
 void emit_mark_varargs(ParmList *l);
-void emit_action(Node *n, Wrapper *f);
-int emit_action_code(Node *n, Wrapper *f, String *action);
+String *emit_action(Node *n);
+int emit_action_code(Node *n, String *wrappercode, String *action);
 void Swig_overload_check(Node *n);
 String *Swig_overload_dispatch(Node *n, const String_or_char *fmt, int *);
 String *Swig_overload_dispatch_cast(Node *n, const String_or_char *fmt, int *);
@@ -334,6 +338,7 @@ String *Swig_class_name(Node *n);
 String *Swig_method_call(String_or_char *name, ParmList *parms);
 String *Swig_method_decl(SwigType *rtype, SwigType *decl, const String_or_char *id, List *args, int strip, int values);
 String *Swig_director_declaration(Node *n);
+void Swig_director_emit_dynamic_cast(Node *n, Wrapper *f);
 /* directors.cxx end */
 
 extern "C" {
@@ -349,11 +354,10 @@ int is_private(Node *n);
 int is_protected(Node *n);
 int is_member_director(Node *parentnode, Node *member);
 int is_member_director(Node *member);
+int is_non_virtual_protected_access(Node *n); /* Check if the non-virtual protected members are required (for directors) */
 int use_naturalvar_mode(Node *n);
 
 void Wrapper_virtual_elimination_mode_set(int);
-void Wrapper_director_mode_set(int);
-void Wrapper_director_protected_mode_set(int);
 void Wrapper_fast_dispatch_mode_set(int);
 void Wrapper_cast_dispatch_mode_set(int);
 void Wrapper_naturalvar_mode_set(int);
