@@ -7,7 +7,7 @@
  * Tcl8 language module for SWIG.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_tcl8_cxx[] = "$Id: tcl8.cxx 10270 2008-02-27 15:29:55Z wsfulton $";
+char cvsroot_tcl8_cxx[] = "$Id: tcl8.cxx 10453 2008-05-15 21:18:44Z wsfulton $";
 
 #include "swigmod.h"
 #include "cparse.h"
@@ -303,8 +303,8 @@ public:
 
     Printv(f->def, "SWIGINTERN int\n ", wname, "(ClientData clientData SWIGUNUSED, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[]) {", NIL);
 
-    /* Print out variables for storing arguments. */
-    emit_args(type, parms, f);
+    // Emit all of the local variables for holding arguments.
+    emit_parameter_variables(parms, f);
 
     /* Attach standard typemaps */
     emit_attach_parmmaps(parms, f);
@@ -443,12 +443,12 @@ public:
     }
 
     /* Now write code to make the function call */
-    emit_action(n, f);
+    String *actioncode = emit_action(n);
 
     /* Need to redo all of this code (eventually) */
 
     /* Return value if necessary  */
-    if ((tm = Swig_typemap_lookup_new("out", n, "result", 0))) {
+    if ((tm = Swig_typemap_lookup_out("out", n, "result", f, actioncode))) {
       Replaceall(tm, "$source", "result");
 #ifdef SWIG_USE_RESULTOBJ
       Replaceall(tm, "$target", "resultobj");
@@ -466,6 +466,7 @@ public:
     } else {
       Swig_warning(WARN_TYPEMAP_OUT_UNDEF, input_file, line_number, "Unable to use return type %s in function %s.\n", SwigType_str(type, 0), name);
     }
+    emit_return_variable(n, type, f);
 
     /* Dump output argument code */
     Printv(f->code, outarg, NIL);
@@ -475,13 +476,13 @@ public:
 
     /* Look for any remaining cleanup */
     if (GetFlag(n, "feature:new")) {
-      if ((tm = Swig_typemap_lookup_new("newfree", n, "result", 0))) {
+      if ((tm = Swig_typemap_lookup("newfree", n, "result", 0))) {
 	Replaceall(tm, "$source", "result");
 	Printf(f->code, "%s\n", tm);
       }
     }
 
-    if ((tm = Swig_typemap_lookup_new("ret", n, "result", 0))) {
+    if ((tm = Swig_typemap_lookup("ret", n, "result", 0))) {
       Replaceall(tm, "$source", "result");
       Printf(f->code, "%s\n", tm);
     }
@@ -565,12 +566,12 @@ public:
     Setattr(n, "wrap:name", getfname);
     Printv(getf->def, "SWIGINTERN const char *", getfname, "(ClientData clientData SWIGUNUSED, Tcl_Interp *interp, char *name1, char *name2, int flags) {", NIL);
     Wrapper_add_local(getf, "value", "Tcl_Obj *value = 0");
-    if ((tm = Swig_typemap_lookup_new("varout", n, name, 0))) {
+    if ((tm = Swig_typemap_lookup("varout", n, name, 0))) {
       Replaceall(tm, "$source", name);
       Replaceall(tm, "$target", "value");
       Replaceall(tm, "$result", "value");
       /* Printf(getf->code, "%s\n",tm); */
-      addfail = emit_action_code(n, getf, tm);
+      addfail = emit_action_code(n, getf->code, tm);
       Printf(getf->code, "if (value) {\n");
       Printf(getf->code, "Tcl_SetVar2(interp,name1,name2,Tcl_GetStringFromObj(value,NULL), flags);\n");
       Printf(getf->code, "Tcl_DecrRefCount(value);\n");
@@ -601,7 +602,7 @@ public:
         Wrapper_add_local(setf, "value", "Tcl_Obj *value = 0");
         Wrapper_add_local(setf, "name1o", "Tcl_Obj *name1o = 0");
 
-        if ((tm = Swig_typemap_lookup_new("varin", n, name, 0))) {
+        if ((tm = Swig_typemap_lookup("varin", n, name, 0))) {
 	  Replaceall(tm, "$source", "value");
 	  Replaceall(tm, "$target", name);
 	  Replaceall(tm, "$input", "value");
@@ -610,7 +611,7 @@ public:
 	  Printf(setf->code, "Tcl_DecrRefCount(name1o);\n");
 	  Printf(setf->code, "if (!value) SWIG_fail;\n");
 	  /* Printf(setf->code,"%s\n", tm); */
-	  emit_action_code(n, setf, tm);
+	  emit_action_code(n, setf->code, tm);
 	  Printf(setf->code, "return NULL;\n");
 	  Printf(setf->code, "fail:\n");
 	  Printf(setf->code, "return \"%s\";\n", iname);
@@ -675,13 +676,13 @@ public:
       value = Char(wname);
     }
 
-    if ((tm = Swig_typemap_lookup_new("consttab", n, name, 0))) {
+    if ((tm = Swig_typemap_lookup("consttab", n, name, 0))) {
       Replaceall(tm, "$source", value);
       Replaceall(tm, "$target", name);
       Replaceall(tm, "$value", value);
       Replaceall(tm, "$nsname", nsname);
       Printf(const_tab, "%s,\n", tm);
-    } else if ((tm = Swig_typemap_lookup_new("constcode", n, name, 0))) {
+    } else if ((tm = Swig_typemap_lookup("constcode", n, name, 0))) {
       Replaceall(tm, "$source", value);
       Replaceall(tm, "$target", name);
       Replaceall(tm, "$value", value);
@@ -782,7 +783,7 @@ public:
       Printv(f_wrappers, "SWIGINTERN void swig_delete_", class_name, "(void *obj) {\n", NIL);
       if (destructor_action) {
 	Printv(f_wrappers, SwigType_str(rt, "arg1"), " = (", SwigType_str(rt, 0), ") obj;\n", NIL);
-	Printv(f_wrappers, destructor_action, NIL);
+	Printv(f_wrappers, destructor_action, "\n", NIL);
       } else {
 	if (CPlusPlus) {
 	  Printv(f_wrappers, "    delete (", SwigType_str(rt, 0), ") obj;\n", NIL);
