@@ -8,7 +8,7 @@
  * error messages.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_error_c[] = "$Id: error.c 9922 2007-08-31 22:20:21Z wsfulton $";
+char cvsroot_error_c[] = "$Id: error.c 10359 2008-04-06 21:21:29Z wsfulton $";
 
 #include "swig.h"
 #include <stdarg.h>
@@ -190,19 +190,22 @@ void Swig_warnfilter(const String_or_char *wlist, int add) {
   c = strtok(c, ", ");
   while (c) {
     if (isdigit((int) *c) || (*c == '+') || (*c == '-')) {
+      /* Even if c is a digit, the rest of the string might not be, eg in the case of typemap 
+       * warnings (a bit odd really), eg: %warnfilter(SWIGWARN_TYPEMAP_CHARLEAK_MSG) */
       if (add) {
 	Insert(filter, 0, c);
 	if (isdigit((int) *c)) {
 	  Insert(filter, 0, "-");
 	}
       } else {
-	char temp[32];
+	char *temp = (char *)malloc(sizeof(char)*strlen(c) + 2);
 	if (isdigit((int) *c)) {
 	  sprintf(temp, "-%s", c);
 	} else {
 	  strcpy(temp, c);
 	}
 	Replace(filter, temp, "", DOH_REPLACE_FIRST);
+        free(temp);
       }
     }
     c = strtok(NULL, ", ");
