@@ -7,7 +7,7 @@
  * Functions for generating various kinds of names during code generation.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_naming_c[] = "$Id: naming.c 10255 2008-02-13 23:43:34Z wsfulton $";
+char cvsroot_naming_c[] = "$Id: naming.c 10540 2008-06-21 15:23:02Z wsfulton $";
 
 #include "swig.h"
 #include "cparse.h"
@@ -482,7 +482,8 @@ DOH *Swig_name_object_get(Hash *namehash, String *prefix, String *name, SwigType
 	Delete(t_name);
       }
       /* A template-based class lookup */
-      if (0 && !rn && SwigType_istemplate(prefix)) {
+      /*
+      if (!rn && SwigType_istemplate(prefix)) {
 	String *t_prefix = SwigType_templateprefix(prefix);
 	if (Strcmp(t_prefix, prefix) != 0) {
 	  String *t_name = SwigType_templateprefix(name);
@@ -491,6 +492,7 @@ DOH *Swig_name_object_get(Hash *namehash, String *prefix, String *name, SwigType
 	}
 	Delete(t_prefix);
       }
+      */
     }
     /* A wildcard-based class lookup */
     if (!rn) {
@@ -966,22 +968,28 @@ int Swig_need_redefined_warn(Node *a, Node *b, int InClass) {
  * int Swig_need_protected(Node* n)
  *
  * Detects when we need to fully register the protected member.
+ * This is basically any protected members when the allprotected mode is set.
+ * Otherwise we take just the protected virtual methods and non-static methods 
+ * (potentially virtual methods) as well as constructors/destructors.
  * 
  * ----------------------------------------------------------------------------- */
 
 int Swig_need_protected(Node *n) {
-  /* First, 'n' looks like a function */
-  /* if (!Swig_director_mode()) return 0; */
   String *nodetype = nodeType(n);
-  if ((Equal(nodetype, "cdecl")) && SwigType_isfunction(Getattr(n, "decl"))) {
-    String *storage = Getattr(n, "storage");
-    /* and the function is declared like virtual, or it has no
-       storage. This eliminates typedef, static and so on. */
-    return !storage || Equal(storage, "virtual");
-  } else if (Equal(nodetype, "constructor") || Equal(nodetype, "destructor")) {
-    return 1;
+  if (checkAttribute(n, "access", "protected")) {
+    if ((Equal(nodetype, "cdecl"))) {
+      if (Swig_director_mode() && Swig_director_protected_mode() && Swig_all_protected_mode()) {
+        return 1;
+      }
+      if (SwigType_isfunction(Getattr(n, "decl"))) {
+        String *storage = Getattr(n, "storage");
+        /* The function is declared virtual, or it has no storage. This eliminates typedef, static etc. */
+        return !storage || Equal(storage, "virtual");
+      }
+    } else if (Equal(nodetype, "constructor") || Equal(nodetype, "destructor")) {
+      return 1;
+    }
   }
-
   return 0;
 }
 
@@ -1471,7 +1479,7 @@ String *Swig_name_make(Node *n, String *prefix, String_or_char *cname, SwigType
   }
 
 
-  if (rename_hash || rename_list) {
+  if (rename_hash || rename_list || namewarn_hash || namewarn_list) {
     Hash *rn = Swig_name_object_get(Swig_name_rename_hash(), prefix, name, decl);
     if (!rn || !Swig_name_match_nameobj(rn, n)) {
       rn = Swig_name_nameobj_lget(Swig_name_rename_list(), n, prefix, name, decl);
@@ -1582,7 +1590,8 @@ String *Swig_name_decl(Node *n) {
   String *decl;
   String *qualifier = Swig_symbol_qualified(n);
   String *name = Swig_scopename_last(Getattr(n, "name"));
-  qualifier = SwigType_namestr(qualifier);
+  if (qualifier)
+    qualifier = SwigType_namestr(qualifier);
 
   /* Very specific hack for template constructors/destructors */
   if (SwigType_istemplate(name)) {
