@@ -10,7 +10,7 @@
  * to easily construct yacc-compatible scanners.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_scanner_c[] = "$Id: scanner.c 10310 2008-03-17 00:36:35Z olly $";
+char cvsroot_scanner_c[] = "$Id: scanner.c 10540 2008-06-21 15:23:02Z wsfulton $";
 
 #include "swig.h"
 #include <ctype.h>
@@ -200,7 +200,7 @@ static char nextchar(Scanner * s) {
   if ((nc == '\n') && (!s->freeze_line)) 
     s->line++;
   Putc(nc,s->text);
-  return nc;
+  return (char)nc;
 }
 
 /* -----------------------------------------------------------------------------
@@ -349,7 +349,7 @@ static void get_escape(Scanner *s) {
       } else {
 	char tmp[3];
 	tmp[0] = '\\';
-	tmp[1] = c;
+	tmp[1] = (char)c;
 	tmp[2] = 0;
 	Delitem(s->text, DOH_END);
 	Append(s->text, tmp);
